@@ -112,8 +112,12 @@ sub push_file_hash ($self, $hash, @files) {
 }
 
 sub move_file_grant ($self, $from_hash, $to_hash, $to_grant) {
+    my $file_list_ref = $self->get_hash_files($from_hash) // [];
+
     $logger->trace("move_file_grant from $from_hash to $to_hash");
-    my @file_list = $self->get_hash_files($from_hash)->@*;
+    my @file_list = $file_list_ref->@*;
+    # since the loops modifies the file list with bremove, we must use
+    # a copy of this list
     foreach my $file (@file_list) {
         $logger->trace("Moving file $file from $from_hash to $to_hash...");
         $self->file_to_grant->{$file} = $to_grant;
@@ -457,9 +461,22 @@ my $__extract_nodejs_info = sub ($c_key, $l_key, $file, $grant, $current_dir) {
             $grant->copyright(new_sc(join("\n", @c_data)));
         }
 
-        my @l_data
-           = ref $data->{$l_key} eq 'ARRAY' ? $data->{$l_key}->@*
-           :                                  $data->{$l_key};
+        my @l_data;
+        # see https://docs.npmjs.com/cli/v6/configuring-npm/package-json
+        if (ref $data->{$l_key} eq 'ARRAY') {
+            # deprecated in package.json
+            if (ref $data->{$l_key}[0] eq 'HASH') {
+                @l_data = map {$_->{type}} $data->{$l_key}->@*;
+            } else {
+                @l_data = $data->{$l_key}->@*;
+            }
+        } elsif (ref $data->{$l_key} eq 'HASH') {
+            # deprecated in package.json
+            @l_data = ($data->{$l_key}{type});
+        } else {
+            @l_data = ($data->{$l_key});
+        }
+
         if (@l_data) {
             $grant->license(join(" or ",@l_data));
         }
